@@ -251,10 +251,11 @@ cb_disk_columns_changed(GtkTreeView *treeview, gpointer user_data)
 }
 
 
-static void open_dir(GtkTreeView       *tree_view,
-                     GtkTreePath       *path,
-                     GtkTreeViewColumn *column,
-                     gpointer           user_data)
+static void
+open_dir(GtkTreeView       *tree_view,
+         GtkTreePath       *path,
+         GtkTreeViewColumn *column,
+         gpointer           user_data)
 {
     GtkTreeIter iter;
     GtkTreeModel *model;
@@ -284,6 +285,44 @@ static void open_dir(GtkTreeView       *tree_view,
     g_free(dir);
 }
 
+static guint timeout_id = 0;
+static GtkTreeViewColumn *current_column;
+
+static gboolean
+save_column_width (gpointer data)
+{
+    gint width;
+    gchar *key;
+    int id;
+    GSettings *settings;
+
+    settings = g_settings_get_child (G_SETTINGS (data), "disktreenew");
+    id = gtk_tree_view_column_get_sort_column_id (current_column);
+    width = gtk_tree_view_column_get_width (current_column);
+
+    key = g_strdup_printf ("col-%d-width", id);
+    g_settings_set_int(settings, key, width);
+    g_free (key);
+
+    if (timeout_id) {
+        g_source_remove (timeout_id);
+        timeout_id = 0;
+    }
+
+    return FALSE;
+}
+
+static void
+cb_disks_column_resized(GtkWidget *widget, GParamSpec *pspec, gpointer data)
+{
+    current_column = GTK_TREE_VIEW_COLUMN(widget);
+
+    if (timeout_id)
+        g_source_remove (timeout_id);
+
+    timeout_id = g_timeout_add (250, save_column_width, data);
+}
+
 GtkWidget *
 create_disk_view(ProcData *procdata)
 {
@@ -305,7 +344,7 @@ create_disk_view(ProcData *procdata)
         N_("Used")
     };
 
-    disk_box = gtk_vbox_new(FALSE, 6);
+    disk_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 
     gtk_container_set_border_width(GTK_CONTAINER(disk_box), 12);
 
@@ -334,7 +373,6 @@ create_disk_view(ProcData *procdata)
     g_signal_connect(G_OBJECT(disk_tree), "row-activated", G_CALLBACK(open_dir), NULL);
     procdata->disk_list = disk_tree;
     gtk_container_add(GTK_CONTAINER(scrolled), disk_tree);
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(disk_tree), TRUE);
     g_object_unref(G_OBJECT(model));
 
     /* icon + device */
@@ -354,6 +392,8 @@ create_disk_view(ProcData *procdata)
     gtk_tree_view_column_set_reorderable(col, TRUE);
     gtk_tree_view_column_set_resizable(col, TRUE);
     gtk_tree_view_column_set_min_width (col, 30);
+    gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
+    g_signal_connect(G_OBJECT(col), "notify::fixed-width", G_CALLBACK(cb_disks_column_resized), procdata->settings);
     gtk_tree_view_append_column(GTK_TREE_VIEW(disk_tree), col);
 
     /* sizes - used */
@@ -363,9 +403,12 @@ create_disk_view(ProcData *procdata)
         col = gtk_tree_view_column_new();
         gtk_tree_view_column_pack_start(col, cell, TRUE);
         gtk_tree_view_column_set_title(col, _(titles[i]));
-        gtk_tree_view_column_set_resizable(col, TRUE);
         gtk_tree_view_column_set_sort_column_id(col, i);
         gtk_tree_view_column_set_reorderable(col, TRUE);
+        gtk_tree_view_column_set_resizable(col, TRUE);
+        gtk_tree_view_column_set_min_width (col, 30);
+        gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
+        g_signal_connect(G_OBJECT(col), "notify::fixed-width", G_CALLBACK(cb_disks_column_resized), procdata->settings);
         gtk_tree_view_append_column(GTK_TREE_VIEW(disk_tree), col);
 
         switch (i) {
@@ -397,16 +440,19 @@ create_disk_view(ProcData *procdata)
                                             &procman::size_cell_data_func,
                                             GUINT_TO_POINTER(DISK_USED),
                                             NULL);
-    gtk_tree_view_column_set_title(col, _(titles[DISK_USED]));
 
     cell = gtk_cell_renderer_progress_new();
     gtk_tree_view_column_pack_start(col, cell, TRUE);
     gtk_tree_view_column_set_attributes(col, cell, "value",
                                         DISK_USED_PERCENTAGE, NULL);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(disk_tree), col);
-    gtk_tree_view_column_set_resizable(col, TRUE);
+    gtk_tree_view_column_set_title(col, _(titles[DISK_USED]));
     gtk_tree_view_column_set_sort_column_id(col, DISK_USED);
     gtk_tree_view_column_set_reorderable(col, TRUE);
+    gtk_tree_view_column_set_resizable(col, TRUE);
+    gtk_tree_view_column_set_min_width (col, 150);
+    gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
+    g_signal_connect(G_OBJECT(col), "notify::fixed-width", G_CALLBACK(cb_disks_column_resized), procdata->settings);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(disk_tree), col);
 
     /* numeric sort */
 
