@@ -204,10 +204,10 @@ create_proc_view (ProcData *procdata)
     GtkWidget *hbox2;
     char* string;
 
-    vbox1 = gtk_vbox_new (FALSE, 18);
+    vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
     gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
 
-    hbox1 = gtk_hbox_new (FALSE, 12);
+    hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
     string = make_loadavg_string ();
@@ -225,7 +225,7 @@ create_proc_view (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (vbox1), scrolled, TRUE, TRUE, 0);
 
 
-    hbox2 = gtk_hbox_new (FALSE, 0);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
 
     procdata->endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
@@ -251,7 +251,11 @@ make_title_label (const char *text)
     label = gtk_label_new (full);
     g_free (full);
 
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
     return label;
@@ -278,19 +282,19 @@ create_sys_view (ProcData *procdata)
     // Translators: color picker title, %s is CPU, Memory, Swap, Receiving, Sending
     title_template = g_strdup(_("Pick a Color for '%s'"));
 
-    vbox = gtk_vbox_new (FALSE, 18);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
 
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
     /* The CPU BOX */
 
-    cpu_box = gtk_vbox_new (FALSE, 6);
+    cpu_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox), cpu_box, TRUE, TRUE, 0);
 
     label = make_title_label (_("CPU History"));
     gtk_box_pack_start (GTK_BOX (cpu_box), label, FALSE, FALSE, 0);
 
-    cpu_graph_box = gtk_vbox_new (FALSE, 6);
+    cpu_graph_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (cpu_box), cpu_graph_box, TRUE, TRUE, 0);
 
     cpu_graph = new LoadGraph(LOAD_GRAPH_CPU);
@@ -300,7 +304,7 @@ create_sys_view (ProcData *procdata)
                         TRUE,
                          0);
 
-    hbox = gtk_hbox_new(FALSE, 0);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     spacer = gtk_label_new ("");
     gtk_widget_set_size_request(GTK_WIDGET(spacer), 57, -1);
     gtk_box_pack_start (GTK_BOX (hbox), spacer,
@@ -310,10 +314,6 @@ create_sys_view (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox,
                         FALSE, FALSE, 0);
 
-    /*cpu_legend_box = gtk_hbox_new(TRUE, 10);
-    gtk_box_pack_start (GTK_BOX (hbox), cpu_legend_box,
-                TRUE, TRUE, 0);*/
-
     GtkWidget* cpu_table = gtk_table_new(std::min(procdata->config.num_cpus / 4, 1),
                                          std::min(procdata->config.num_cpus, 4),
                                          TRUE);
@@ -324,17 +324,14 @@ create_sys_view (ProcData *procdata)
     for (i=0;i<procdata->config.num_cpus; i++) {
         GtkWidget *temp_hbox;
 
-        temp_hbox = gtk_hbox_new (FALSE, 0);
+        temp_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_table_attach(GTK_TABLE(cpu_table), temp_hbox,
                  i % 4, i % 4 + 1,
                  i / 4, i / 4 + 1,
                  static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL),
                  static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL),
                  0, 0);
-        //gtk_size_group_add_widget (sizegroup, temp_hbox);
-        /*g_signal_connect (G_OBJECT (temp_hbox), "size_request",
-                     G_CALLBACK(size_request), &cpu_size);
-*/
+
         color_picker = gsm_color_button_new (&cpu_graph->colors.at(i), GSMCP_TYPE_CPU);
         g_signal_connect (G_OBJECT (color_picker), "color_set",
                           G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
@@ -353,7 +350,11 @@ create_sys_view (ProcData *procdata)
         g_free (label_text);
 
         cpu_label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+        gtk_label_set_xalign (GTK_LABEL (cpu_label), 0.0);
+#else
         gtk_misc_set_alignment (GTK_MISC (cpu_label), 0.0, 0.5);
+#endif
         gtk_box_pack_start (GTK_BOX (temp_hbox), cpu_label, TRUE, TRUE, 0);
         load_graph_get_labels(cpu_graph)->cpu[i] = cpu_label;
 
@@ -361,13 +362,13 @@ create_sys_view (ProcData *procdata)
 
     procdata->cpu_graph = cpu_graph;
 
-    mem_box = gtk_vbox_new (FALSE, 6);
+    mem_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox), mem_box, TRUE, TRUE, 0);
 
     label = make_title_label (_("Memory and Swap History"));
     gtk_box_pack_start (GTK_BOX (mem_box), label, FALSE, FALSE, 0);
 
-    mem_graph_box = gtk_vbox_new (FALSE, 6);
+    mem_graph_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (mem_box), mem_graph_box, TRUE, TRUE, 0);
 
 
@@ -378,7 +379,7 @@ create_sys_view (ProcData *procdata)
                         TRUE,
                         0);
 
-    hbox = gtk_hbox_new(FALSE, 0);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     spacer = gtk_label_new ("");
     gtk_widget_set_size_request(GTK_WIDGET(spacer), 54, -1);
     gtk_box_pack_start (GTK_BOX (hbox), spacer,
@@ -388,7 +389,7 @@ create_sys_view (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (mem_graph_box), hbox,
                         FALSE, FALSE, 0);
 
-    mem_legend_box = gtk_hbox_new(TRUE, 10);
+    mem_legend_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
     gtk_box_pack_start (GTK_BOX (hbox), mem_legend_box,
                         TRUE, TRUE, 0);
 
@@ -409,7 +410,11 @@ create_sys_view (ProcData *procdata)
 
     label = gtk_label_new (label_text);
     g_free(label_text);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 7, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
     gtk_table_attach (GTK_TABLE (table),
@@ -440,7 +445,11 @@ create_sys_view (ProcData *procdata)
 
     label = gtk_label_new (label_text);
     g_free(label_text);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 7, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
     gtk_table_attach (GTK_TABLE (table),
@@ -457,13 +466,13 @@ create_sys_view (ProcData *procdata)
     procdata->mem_graph = mem_graph;
 
     /* The net box */
-    net_box = gtk_vbox_new (FALSE, 6);
+    net_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox), net_box, TRUE, TRUE, 0);
 
     label = make_title_label (_("Network History"));
     gtk_box_pack_start (GTK_BOX (net_box), label, FALSE, FALSE, 0);
 
-    net_graph_box = gtk_vbox_new (FALSE, 6);
+    net_graph_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (net_box), net_graph_box, TRUE, TRUE, 0);
 
     net_graph = new LoadGraph(LOAD_GRAPH_NET);
@@ -473,7 +482,7 @@ create_sys_view (ProcData *procdata)
                         TRUE,
                         0);
 
-    hbox = gtk_hbox_new(FALSE, 0);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     spacer = gtk_label_new ("");
     gtk_widget_set_size_request(GTK_WIDGET(spacer), 54, -1);
     gtk_box_pack_start (GTK_BOX (hbox), spacer,
@@ -483,7 +492,7 @@ create_sys_view (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (net_graph_box), hbox,
                         FALSE, FALSE, 0);
 
-    net_legend_box = gtk_hbox_new(TRUE, 10);
+    net_legend_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
     gtk_box_pack_start (GTK_BOX (hbox), net_legend_box,
                         TRUE, TRUE, 0);
 
@@ -506,33 +515,40 @@ create_sys_view (ProcData *procdata)
 
     label = gtk_label_new (label_text);
     g_free(label_text);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (load_graph_get_labels(net_graph)->net_in), 1.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_in),
                             1.0,
                             0.5);
-/*
-    hbox = gtk_hbox_new (FALSE, 0);
-    g_signal_connect (G_OBJECT (hbox), "size_request",
-                      G_CALLBACK(size_request), &net_size);
-    gtk_box_pack_start (GTK_BOX (hbox),
-                        load_graph_get_labels(net_graph)->net_in,
-                        TRUE,
-                        TRUE,
-                        0);
-*/
+#endif
+
     gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_in), 100, -1);
     gtk_table_attach (GTK_TABLE (table), load_graph_get_labels(net_graph)->net_in, 2, 3, 0, 1,
                       static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL), GTK_FILL, 0, 0);
 
     label = gtk_label_new (_("Total Received"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (load_graph_get_labels(net_graph)->net_in_total), 1.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_in_total),
                             1.0,
                             0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table),
                       load_graph_get_labels(net_graph)->net_in_total,
                       2,
@@ -567,34 +583,40 @@ create_sys_view (ProcData *procdata)
 
     label = gtk_label_new (label_text);
     g_free(label_text);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (load_graph_get_labels(net_graph)->net_out), 1.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_out),
                             1.0,
                             0.5);
-/*
-    hbox = gtk_hbox_new (FALSE, 0);
-    g_signal_connect (G_OBJECT (load_graph_get_labels(net_graph)->net_out), "size_request",
-                      G_CALLBACK(size_request), &net_size);
+#endif
 
-    gtk_box_pack_start (GTK_BOX (hbox),
-                        load_graph_get_labels(net_graph)->net_out,
-                        TRUE,
-                        TRUE,
-                        0);
-*/
     gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_out), 100, -1);
     gtk_table_attach (GTK_TABLE (table), load_graph_get_labels(net_graph)->net_out, 2, 3, 0, 1,
                       static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL), GTK_FILL, 0, 0);
 
     label = gtk_label_new (_("Total Sent"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (load_graph_get_labels(net_graph)->net_out_total), 1.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_out_total),
                             1.0,
                             0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table),
                       load_graph_get_labels(net_graph)->net_out_total,
                       2,
@@ -690,19 +712,12 @@ create_main_window (ProcData *procdata)
     gtk_window_set_title(GTK_WINDOW(app), _("System Monitor"));
 
     GdkScreen* screen = gtk_widget_get_screen(app);
-#if GTK_CHECK_VERSION(3,0,0)
     /* use visual, if available */
     GdkVisual* visual = gdk_screen_get_rgba_visual(screen);
     if (visual)
         gtk_widget_set_visual(app, visual);
-#else
-    /* use rgba colormap, if available */
-    GdkColormap* colormap = gdk_screen_get_rgba_colormap(screen);
-    if (colormap)
-        gtk_widget_set_default_colormap(colormap);
-#endif
 
-    main_box = gtk_vbox_new (FALSE, 0);
+    main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(app), main_box);
 
     width = procdata->config.width;
@@ -712,6 +727,9 @@ create_main_window (ProcData *procdata)
     gtk_window_set_default_size (GTK_WINDOW (app), width, height);
     gtk_window_move(GTK_WINDOW (app), xpos, ypos);
     gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
+    if (procdata->config.maximized) {
+        gtk_window_maximize(GTK_WINDOW(app));
+    }
 
     /* create the menubar */
     procdata->uimanager = gtk_ui_manager_new ();
@@ -770,7 +788,7 @@ create_main_window (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (main_box), notebook, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (notebook), 12);
 
-    sysinfo_box = gtk_hbox_new(TRUE, 0); // procman_create_sysinfo_view();
+    sysinfo_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0); // procman_create_sysinfo_view();
     sysinfo_label = gtk_label_new(_("System"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sysinfo_box, sysinfo_label);
 
