@@ -33,10 +33,10 @@
 #include "util.h"
 #include "load-graph.h"
 #include "settings-keys.h"
-#include "procman_matesu.h"
 #include "procman_gksu.h"
 #include "cgroups.h"
 
+
 static GtkWidget *renice_dialog = NULL;
 static GtkWidget *prefs_dialog = NULL;
 static gint new_nice_value = 0;
@@ -69,7 +69,7 @@ procdialog_create_kill_dialog (ProcData *procdata, int signal)
 
     if (signal == SIGKILL) {
         /*xgettext: primary alert message*/
-        primary = g_strdup_printf (_("Kill the selected process »%s« (PID: %u)?"),
+        primary = g_strdup_printf (_("Kill the selected process “%s” (PID: %u)?"),
                                    procdata->selected_process->name,
                                    procdata->selected_process->pid);
         /*xgettext: secondary alert message*/
@@ -80,7 +80,7 @@ procdialog_create_kill_dialog (ProcData *procdata, int signal)
     }
     else {
         /*xgettext: primary alert message*/
-        primary = g_strdup_printf (_("End the selected process »%s« (PID: %u)?"),
+        primary = g_strdup_printf (_("End the selected process “%s” (PID: %u)?"),
                                    procdata->selected_process->name,
                                    procdata->selected_process->pid);
         /*xgettext: secondary alert message*/
@@ -153,11 +153,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
     GtkWidget *label;
     GtkWidget *priority_label;
     GtkWidget *table;
-#if GTK_CHECK_VERSION(3,0,0)
     GtkAdjustment *renice_adj;
-#else
-    GtkObject *renice_adj;
-#endif
     GtkWidget *hscale;
     GtkWidget *button;
     GtkWidget *icon;
@@ -170,7 +166,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
     if (!info)
         return;
 
-    dialog_title = g_strdup_printf (_("Change Priority of Process »%s« (PID: %u)"),
+    dialog_title = g_strdup_printf (_("Change Priority of Process “%s” (PID: %u)"),
                                     info->name, info->pid);
     dialog = gtk_dialog_new_with_buttons (dialog_title, NULL,
                                           GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -196,7 +192,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
     gtk_box_set_spacing (GTK_BOX (dialog_vbox), 2);
     gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 5);
 
-    vbox = gtk_vbox_new (FALSE, 12);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
     gtk_box_pack_start (GTK_BOX (dialog_vbox), vbox, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
@@ -211,11 +207,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
 
     renice_adj = gtk_adjustment_new (info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
     new_nice_value = 0;
-#if GTK_CHECK_VERSION (3, 0, 0)
     hscale = gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, renice_adj);
-#else
-    hscale = gtk_hscale_new (GTK_ADJUSTMENT (renice_adj));
-#endif
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), hscale);
     gtk_scale_set_digits (GTK_SCALE (hscale), 0);
     gtk_table_attach (GTK_TABLE (table), hscale, 1, 2, 0, 1,
@@ -363,17 +355,15 @@ private:
 };
 
 
-
-
 static void
-field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+field_toggled (const gchar *child_schema, GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
     GtkTreeModel *model = static_cast<GtkTreeModel*>(data);
     GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
     GtkTreeIter iter;
     GtkTreeViewColumn *column;
     gboolean toggled;
-    GSettings *settings = g_settings_get_child (ProcData::get_instance()->settings, "proctree");
+    GSettings *settings = g_settings_get_child (ProcData::get_instance()->settings, child_schema);
     gchar *key;
     int id;
 
@@ -395,11 +385,22 @@ field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
     g_free (key);
 
     gtk_tree_path_free (path);
+}
 
+static void
+proc_field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+{
+    field_toggled ("proctree", cell, path_str, data);
+}
+
+static void
+disk_field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+{
+    field_toggled ("disktreenew", cell, path_str, data);
 }
 
 static GtkWidget *
-create_field_page(GtkWidget *tree, const char* text)
+create_field_page(GtkWidget *tree, const gchar *child_schema, const gchar *text)
 {
     GtkWidget *vbox;
     GtkWidget *scrolled;
@@ -410,10 +411,14 @@ create_field_page(GtkWidget *tree, const char* text)
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
 
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 
     label = gtk_label_new_with_mnemonic (text);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
     scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -437,7 +442,11 @@ create_field_page(GtkWidget *tree, const char* text)
     gtk_tree_view_column_set_attributes (column, cell,
                                          "active", 0,
                                          NULL);
-    g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (field_toggled), model);
+    if (g_strcmp0 (child_schema, "proctree") == 0)
+        g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (proc_field_toggled), model);
+    else if (g_strcmp0 (child_schema, "disktreenew") == 0)
+        g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (disk_field_toggled), model);
+
     gtk_tree_view_column_set_clickable (column, TRUE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
@@ -534,7 +543,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     /* driven by window childs. The problem is that the fields list */
     /* have to show at least 4 items to respect HIG. I don't know   */
     /* any function to set list height by contents/items inside it. */
-    gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 420);
+    gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 500);
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
     prefs_dialog = dialog;
 
@@ -545,39 +554,47 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
     gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
 
-    proc_box = gtk_vbox_new (FALSE, 18);
+    proc_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
     gtk_container_set_border_width (GTK_CONTAINER (proc_box), 12);
     tab_label = gtk_label_new (_("Processes"));
     gtk_widget_show (tab_label);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proc_box, tab_label);
 
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (proc_box), vbox, FALSE, FALSE, 0);
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Behavior"));
     label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 
-    hbox2 = gtk_hbox_new (FALSE, 12);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 
-    hbox3 = gtk_hbox_new (FALSE, 6);
+    hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
 
     update = (gfloat) procdata->config.update_interval;
@@ -586,7 +603,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
                                    MAX_UPDATE_INTERVAL / 1000,
                                    0.25,
                                    1.0,
-                                   1.0);
+                                   0);
 
     spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
     gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
@@ -595,7 +612,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 
 
-    hbox2 = gtk_hbox_new(FALSE, 6);
+    hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start(GTK_BOX(vbox2), hbox2, FALSE, FALSE, 0);
 
     smooth_button = gtk_check_button_new_with_mnemonic(_("Enable _smooth refresh"));
@@ -608,7 +625,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 
 
-    hbox2 = gtk_hbox_new (FALSE, 6);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     check_button = gtk_check_button_new_with_mnemonic (_("Alert before ending or _killing processes"));
@@ -621,7 +638,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 
 
-    hbox2 = gtk_hbox_new(FALSE, 6);
+    hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start(GTK_BOX(vbox2), hbox2, FALSE, FALSE, 0);
 
     GtkWidget *solaris_button = gtk_check_button_new_with_mnemonic(_("Divide CPU usage by CPU count"));
@@ -636,67 +653,79 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 
 
-    hbox2 = gtk_hbox_new (FALSE, 6);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (proc_box), vbox, TRUE, TRUE, 0);
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Information Fields"));
     label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    vbox2 = create_field_page (procdata->tree, _("Process i_nformation shown in list:"));
+    vbox2 = create_field_page (procdata->tree, "proctree", _("Process i_nformation shown in list:"));
     gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 
-    sys_box = gtk_vbox_new (FALSE, 12);
+    sys_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
     gtk_container_set_border_width (GTK_CONTAINER (sys_box), 12);
     tab_label = gtk_label_new (_("Resources"));
     gtk_widget_show (tab_label);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label);
 
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (sys_box), vbox, FALSE, FALSE, 0);
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Graphs"));
     label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 
-    hbox2 = gtk_hbox_new (FALSE, 12);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
     gtk_size_group_add_widget (size, label);
 
-    hbox3 = gtk_hbox_new (FALSE, 6);
+    hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
 
     update = (gfloat) procdata->config.graph_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0, 0.25,
-                                                      100.0, 0.25, 1.0, 1.0);
+                                                      100.0, 0.25, 1.0, 0);
     spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
     g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
                       G_CALLBACK(SBU::callback),
@@ -717,13 +746,13 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 
 
-    hbox2 = gtk_hbox_new (FALSE, 12);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
 
     /*
      * Devices
      */
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
     tab_label = gtk_label_new (_("File Systems"));
     gtk_widget_show (tab_label);
@@ -731,33 +760,41 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("File Systems"));
     label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 
-    hbox2 = gtk_hbox_new (FALSE, 12);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 
-    hbox3 = gtk_hbox_new (FALSE, 6);
+    hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
 
     update = (gfloat) procdata->config.disks_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new (update / 1000.0, 1.0,
-                                                       100.0, 1.0, 1.0, 1.0);
+                                                       100.0, 1.0, 1.0, 0);
     spin_button = gtk_spin_button_new (adjustment, 1.0, 0);
     gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
@@ -766,7 +803,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
                       &disks_interval_updater);
 
 
-    hbox2 = gtk_hbox_new (FALSE, 6);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
     check_button = gtk_check_button_new_with_mnemonic (_("Show _all file systems"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
@@ -776,7 +813,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
 
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new ("    ");
@@ -784,18 +821,22 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Information Fields"));
     label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    vbox3 = create_field_page (procdata->disk_list, _("File system i_nformation shown in list:"));
+    vbox3 = create_field_page (procdata->disk_list, "disktreenew", _("File system i_nformation shown in list:"));
     gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0);
 
     gtk_widget_show_all (dialog);
@@ -855,8 +896,6 @@ procdialog_create_root_password_dialog(ProcmanActionType type,
 
     if (procman_has_gksu())
         ret = procman_gksu_create_root_password_dialog(command);
-    else if (procman_has_matesu())
-        ret = procman_matesu_create_root_password_dialog(command);
 
     g_free(command);
     return ret;
