@@ -33,6 +33,8 @@
 #include <bacon-message-connection.h>
 #include <glibtop.h>
 #include <glibtop/close.h>
+#include <glibtop/cpu.h>
+#include <glibtop/sysinfo.h>
 #include <glibtop/loadavg.h>
 
 #include "load-graph.h"
@@ -91,7 +93,7 @@ tree_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 
     proctable_clear_tree (procdata);
 
-    proctable_update_all (procdata);
+    proctable_update (procdata);
 }
 
 static void
@@ -100,7 +102,7 @@ solaris_mode_changed_cb(GSettings *settings, const gchar *key, gpointer data)
     ProcData *procdata = static_cast<ProcData*>(data);
 
     procdata->config.solaris_mode = g_settings_get_boolean(settings, key);
-    proctable_update_all (procdata);
+    proctable_update (procdata);
 }
 
 
@@ -123,7 +125,7 @@ view_as_changed_cb (GSettings *settings, const gchar *key, gpointer data)
     procdata->config.whose_process = g_settings_get_int (settings, key);
     procdata->config.whose_process = CLAMP (procdata->config.whose_process, 0, 2);
     proctable_clear_tree (procdata);
-    proctable_update_all (procdata);
+    proctable_update (procdata);
 
 }
 
@@ -195,26 +197,26 @@ color_changed_cb (GSettings *settings, const gchar *key, gpointer data)
         for (int i = 0; i < procdata->config.num_cpus; i++) {
             string cpu_key = make_string(g_strdup_printf("cpu-color%d", i));
             if (cpu_key == key) {
-                gdk_color_parse (color, &procdata->config.cpu_color[i]);
+                gdk_rgba_parse (&procdata->config.cpu_color[i], color);
                 procdata->cpu_graph->colors.at(i) = procdata->config.cpu_color[i];
                 break;
             }
         }
     }
     else if (g_str_equal (key, "mem-color")) {
-        gdk_color_parse (color, &procdata->config.mem_color);
+        gdk_rgba_parse (&procdata->config.mem_color, color);
         procdata->mem_graph->colors.at(0) = procdata->config.mem_color;
     }
     else if (g_str_equal (key, "swap-color")) {
-        gdk_color_parse (color, &procdata->config.swap_color);
+        gdk_rgba_parse (&procdata->config.swap_color, color);
         procdata->mem_graph->colors.at(1) = procdata->config.swap_color;
     }
     else if (g_str_equal (key, "net-in-color")) {
-        gdk_color_parse (color, &procdata->config.net_in_color);
+        gdk_rgba_parse (&procdata->config.net_in_color, color);
         procdata->net_graph->colors.at(0) = procdata->config.net_in_color;
     }
     else if (g_str_equal (key, "net-out-color")) {
-        gdk_color_parse (color, &procdata->config.net_out_color);
+        gdk_rgba_parse (&procdata->config.net_out_color, color);
         procdata->net_graph->colors.at(1) = procdata->config.net_out_color;
     }
     else {
@@ -239,12 +241,10 @@ show_all_fs_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 static ProcData *
 procman_data_new (GSettings *settings)
 {
-
     ProcData *pd;
     gchar *color;
     gchar **keys;
     gint swidth, sheight;
-    gint i;
     glibtop_cpu cpu;
 
     pd = ProcData::get_instance();
@@ -253,6 +253,8 @@ procman_data_new (GSettings *settings)
                     &pd->config.width, &pd->config.height,
                     &pd->config.xpos, &pd->config.ypos);
 
+    pd->config.maximized = g_settings_get_boolean(settings, "maximized");
+
     pd->config.show_tree = g_settings_get_boolean (settings, "show-tree");
     g_signal_connect (G_OBJECT(settings), "changed::show-tree", G_CALLBACK(tree_changed_cb), pd);
 
@@ -285,17 +287,10 @@ procman_data_new (GSettings *settings)
     g_signal_connect (G_OBJECT(settings), "changed::view-as", G_CALLBACK(view_as_changed_cb),pd);
     pd->config.current_tab = g_settings_get_int (settings, "current-tab");
 
-    /* Determinie number of cpus since libgtop doesn't really tell you*/
-    pd->config.num_cpus = 0;
     glibtop_get_cpu (&cpu);
     pd->frequency = cpu.frequency;
-    i=0;
-    while (i < GLIBTOP_NCPU && cpu.xcpu_total[i] != 0) {
-        pd->config.num_cpus ++;
-        i++;
-    }
-    if (pd->config.num_cpus == 0)
-        pd->config.num_cpus = 1;
+
+    pd->config.num_cpus = glibtop_get_sysinfo()->ncpu; // or server->ncpu + 1
 
     keys = g_settings_list_keys (settings);
     for (int i = 0; i < pd->config.num_cpus; i++) {
@@ -309,7 +304,7 @@ procman_data_new (GSettings *settings)
         detail_string = std::string("changed::") + std::string(key);
         g_signal_connect (G_OBJECT(settings), detail_string.c_str(),
                           G_CALLBACK(color_changed_cb), pd);
-        gdk_color_parse(color, &pd->config.cpu_color[i]);
+        gdk_rgba_parse (&pd->config.cpu_color[i], color);
         g_free (color);
         g_free (key);
     }
@@ -319,7 +314,7 @@ procman_data_new (GSettings *settings)
         color = g_strdup ("#000000ff0082");
     g_signal_connect (G_OBJECT(settings), "changed::mem-color",
                       G_CALLBACK(color_changed_cb), pd);
-    gdk_color_parse(color, &pd->config.mem_color);
+    gdk_rgba_parse (&pd->config.mem_color, color);
 
     g_free (color);
 
@@ -328,7 +323,7 @@ procman_data_new (GSettings *settings)
         color = g_strdup ("#00b6000000ff");
     g_signal_connect (G_OBJECT(settings), "changed::swap-color",
                       G_CALLBACK(color_changed_cb), pd);
-    gdk_color_parse(color, &pd->config.swap_color);
+    gdk_rgba_parse (&pd->config.swap_color, color);
     g_free (color);
 
     color = g_settings_get_string (settings, "net-in-color");
@@ -336,7 +331,7 @@ procman_data_new (GSettings *settings)
         color = g_strdup ("#000000f200f2");
     g_signal_connect (G_OBJECT(settings), "changed::net-in-color",
                       G_CALLBACK(color_changed_cb), pd);
-    gdk_color_parse(color, &pd->config.net_in_color);
+    gdk_rgba_parse (&pd->config.net_in_color, color);
     g_free (color);
 
     color = g_settings_get_string (settings, "net-out-color");
@@ -344,7 +339,7 @@ procman_data_new (GSettings *settings)
         color = g_strdup ("#00f2000000c1");
     g_signal_connect (G_OBJECT(settings), "changed::net-out-color",
                       G_CALLBACK(color_changed_cb), pd);
-    gdk_color_parse(color, &pd->config.net_out_color);
+    gdk_rgba_parse (&pd->config.net_out_color, color);
     g_free (color);
 
     /* Sanity checks */
@@ -404,9 +399,10 @@ procman_get_tree_state (GSettings *settings, GtkWidget *tree, const gchar *child
 
     columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 
-    if(!g_strcmp0(child_schema, "proctree"))
+    if (g_strcmp0(child_schema, "proctree") == 0 ||
+        g_strcmp0(child_schema, "disktreenew") == 0)
     {
-        for(it = columns; it; it = it->next)
+        for (it = columns; it; it = it->next)
         {
             GtkTreeViewColumn *column;
             gint width;
@@ -426,19 +422,17 @@ procman_get_tree_state (GSettings *settings, GtkWidget *tree, const gchar *child
             g_free (key);
 
             column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), id);
-            if(!column) continue;
-                gtk_tree_view_column_set_visible (column, visible);
-                if (visible) {
-                    /* ensure column is really visible */
-                    width = MAX(width, 10);
-                    gtk_tree_view_column_set_fixed_width(column, width);
-              }
-         }
-    }
+            if (column == NULL)
+                continue;
+
+            gtk_tree_view_column_set_visible (column, visible);
+            if (visible) {
+                /* ensure column is really visible */
+                width = MAX(width, 20);
+                gtk_tree_view_column_set_fixed_width(column, width);
+            }
+        }
 
-    if(!g_strcmp0(child_schema, "proctree") ||
-       !g_strcmp0(child_schema, "disktreenew"))
-    {
         GVariant *value;
         GVariantIter iter;
         int sortIndex;
@@ -487,7 +481,8 @@ procman_save_tree_state (GSettings *settings, GtkWidget *tree, const gchar *chil
 
     columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 
-    if(!g_strcmp0(child_schema, "proctree") || !g_strcmp0(child_schema, "disktreenew"))
+    if (g_strcmp0(child_schema, "proctree") == 0 ||
+        g_strcmp0(child_schema, "disktreenew") == 0)
     {
         GSList *order;
         GSList *order_node;
@@ -498,8 +493,8 @@ procman_save_tree_state (GSettings *settings, GtkWidget *tree, const gchar *chil
 
         builder = g_variant_builder_new (G_VARIANT_TYPE_ARRAY);
 
-        for(order_node = order; order_node; order_node = order_node->next)
-        g_variant_builder_add(builder, "i", GPOINTER_TO_INT(order_node->data));
+        for (order_node = order; order_node; order_node = order_node->next)
+            g_variant_builder_add(builder, "i", GPOINTER_TO_INT(order_node->data));
 
         order_variant = g_variant_new("ai", builder);
         g_settings_set_value(pt_settings, "columns-order", order_variant);
@@ -518,13 +513,21 @@ procman_save_config (ProcData *data)
 
     g_assert(data);
 
-    data->config.width = gdk_window_get_width(gtk_widget_get_window(data->app));
-    data->config.height = gdk_window_get_height(gtk_widget_get_window(data->app));
-    gtk_window_get_position(GTK_WINDOW(data->app), &data->config.xpos, &data->config.ypos);
+    data->config.maximized = gdk_window_get_state(gtk_widget_get_window (data->app)) & GDK_WINDOW_STATE_MAXIMIZED;
+    if (!data->config.maximized) {
+        // we only want to store/overwrite size and position info with non-maximized state info
+        data->config.width = gdk_window_get_width(gtk_widget_get_window(data->app));
+        data->config.height = gdk_window_get_height(gtk_widget_get_window(data->app));
+
+        gtk_window_get_position(GTK_WINDOW(data->app), &data->config.xpos, &data->config.ypos);
+
+        g_settings_set (settings, "window-state", "(iiii)",
+                        data->config.width, data->config.height,
+                        data->config.xpos, data->config.ypos);
+    }
+
+    g_settings_set_boolean (settings, "maximized", data->config.maximized);
 
-    g_settings_set (settings, "window-state", "(iiii)",
-                    data->config.width, data->config.height,
-                    data->config.xpos, data->config.ypos);
     g_settings_set_int (settings, "current-tab", data->config.current_tab);
 }
 
@@ -722,7 +725,7 @@ main (int argc, char *argv[])
     create_main_window (procdata);
     procman_debug("end create_main_window");
 
-    // proctable_update_all (procdata);
+    // proctable_update (procdata);
 
     init_volume_monitor (procdata);
 
